@@ -18,7 +18,7 @@
 //
 // to contact the author : dar.linux@free.fr
 /*********************************************************************/
-// $Id: filesystem.cpp,v 1.35.2.1 2005/02/11 16:09:30 edrusb Rel $
+// $Id: filesystem.cpp,v 1.35.2.5 2005/09/08 19:20:21 edrusb Rel $
 //
 /*********************************************************************/
 
@@ -76,10 +76,10 @@ char *strchr (), *strrchr ();
 #if HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
 #endif
-#if LIBDAR_NODUMP_FEATURE == linux
+#if LIBDAR_NODUMP_FEATURE == NODUMP_LINUX
 #include <linux/ext2_fs.h>
 #else
-#if LIBDAR_NODUMP_FEATURE == ext2fs
+#if LIBDAR_NODUMP_FEATURE == NODUMP_EXT2FS
 #include <ext2fs/ext2_fs.h>
 #else
 #error "unknown location of ext2_fs.h include file"
@@ -299,10 +299,10 @@ namespace libdar
         }
         catch(...)
         {
-            delete ptr_name;
+            delete [] ptr_name;
             throw;
         }
-        delete ptr_name;
+        delete [] ptr_name;
 
         return ref;
 
@@ -436,17 +436,20 @@ namespace libdar
         }
         catch(...)
         {
-            delete tmp;
+            delete [] tmp;
             throw;
         }
-        delete tmp;
+        delete [] tmp;
     }
 
 
-    bool filesystem_backup::read(entree * & ref)
+    bool filesystem_backup::read(entree * & ref, infinint & errors, infinint & skipped_dump)
     {
         bool once_again;
         ref = NULL;
+	errors = 0;
+	skipped_dump = 0;
+
 
         if(current_dir == NULL)
             throw SRC_BUG; // constructor not called or badly implemented.
@@ -518,7 +521,8 @@ namespace libdar
 					    catch(Egeneric & e)
 					    {
 						delete ref;
-						ref = NULL; // we ignore this directory and skip to the next one
+						ref = NULL; // we ignore this directory and skip to the next entry
+						errors++;
 						if(! current_dir->pop(tmp))
 						    throw SRC_BUG;
 					    }
@@ -526,10 +530,10 @@ namespace libdar
 				    }
 				    catch(...)
 				    {
-					delete ptr_name;
+					delete [] ptr_name;
 					throw;
 				    }
-				    delete ptr_name;
+				    delete [] ptr_name;
 				}
 
 				if(ref == NULL)
@@ -537,6 +541,7 @@ namespace libdar
 				    // the file has been removed between the time
 				    // the directory has been openned, and the time
 				    // we try to read it, so we ignore it.
+				    // this case is silently ignored and not counted
 			    }
 			    catch(...)
 			    {
@@ -552,13 +557,15 @@ namespace libdar
                         {
                             if(info_details)
                                 get_fs_ui().warning(string(gettext("Ignoring file with NODUMP flag set: ")) + (*current_dir + name).display());
+			    skipped_dump++;
                             once_again = true;
                         }
                     }
                     catch(Erange & e)
                     {
-                        get_fs_ui().warning(string(gettext("Error reading directory contents : ")) + e.get_message() + gettext(" . Ignoring file or directory"));
+                        get_fs_ui().warning(string(gettext("Error reading directory contents: ")) + e.get_message() + gettext(" . Ignoring file or directory"));
                         once_again = true;
+			errors++;
                     }
                 }
             }
@@ -652,10 +659,10 @@ namespace libdar
         }
         catch(...)
         {
-            delete tmp;
+            delete [] tmp;
             throw;
         }
-        delete tmp;
+        delete [] tmp;
     }
 
     bool filesystem_diff::read_filename(const string & name, nomme * &ref)
@@ -940,10 +947,10 @@ namespace libdar
                         }
                         catch(...)
                         {
-                            delete old;
+                            delete [] old;
                             throw;
                         }
-                        delete old;
+                        delete [] old;
                     }
 
                     if(create_file)
@@ -999,7 +1006,7 @@ namespace libdar
                 {
                     char *cible = tools_str2charptr(ref_lie->get_target());
                     ret = symlink(cible ,name);
-                    delete cible;
+                    delete [] cible;
                 }
                 else if(ref_blo != NULL)
                     ret = mknod(name, S_IFBLK | 0700, makedev(ref_blo->get_major(), ref_blo->get_minor()));
@@ -1049,10 +1056,10 @@ namespace libdar
         }
         catch(...)
         {
-            delete name;
+            delete [] name;
             throw;
         }
-        delete name;
+        delete [] name;
     }
 
     void filesystem_hard_link_write::clear_corres(const infinint & ligne)
@@ -1328,10 +1335,10 @@ namespace libdar
                     }
                     catch(...)
                     {
-                        delete name;
+                        delete [] name;
                         throw;
                     }
-                    delete name;
+                    delete [] name;
                 }
             }
         }
@@ -1419,16 +1426,16 @@ namespace libdar
         }
         catch(...)
         {
-            delete s;
+            delete [] s;
             throw;
         }
 
-        delete s;
+        delete [] s;
     }
 
     static void dummy_call(char *x)
     {
-        static char id[]="$Id: filesystem.cpp,v 1.35.2.1 2005/02/11 16:09:30 edrusb Rel $";
+        static char id[]="$Id: filesystem.cpp,v 1.35.2.5 2005/09/08 19:20:21 edrusb Rel $";
         dummy_call(id);
     }
 
@@ -1499,10 +1506,10 @@ namespace libdar
         }
         catch(...)
         {
-            delete name;
+            delete [] name;
             throw;
         }
-        delete name;
+        delete [] name;
     }
 
     static void attach_ea(const string &chemin, inode *ino, bool ea_root_mode, bool ea_user_mode)
@@ -1567,10 +1574,10 @@ namespace libdar
         }
         catch(...)
         {
-            delete ptr;
+            delete [] ptr;
             throw;
         }
-        delete ptr;
+        delete [] ptr;
 
         return (f & EXT2_NODUMP_FL) != 0;
 #else
@@ -1618,14 +1625,14 @@ namespace libdar
 		    dialog.warning(tools_printf(gettext("Replacing %s in the -R option by the directory pointed to by this symbolic link: "), ptr) + ret->display());
 	    }
 	    else // not a directory given as argument
-		throw Erange("filesystem:get_root_with_symlink", tools_printf(gettext("The given path %s must be a directory (or symbolic link to an existing directory"), ptr));
+		throw Erange("filesystem:get_root_with_symlink", tools_printf(gettext("The given path %s must be a directory (or symbolic link to an existing directory)"), ptr));
 	}
 	catch(...)
 	{
-	    delete ptr;
+	    delete [] ptr;
 	    throw;
 	}
-	delete ptr;
+	delete [] ptr;
 	if(ret == NULL)
 	    throw SRC_BUG; // exit without exception, but ret not allocated !
 
@@ -1646,10 +1653,10 @@ namespace libdar
 	}
 	catch(...)
 	{
-	    delete ptr;
+	    delete [] ptr;
 	    throw;
 	}
-	delete ptr;
+	delete [] ptr;
 	return ret;
     }
 
